
# Slot: mode


One of {"auto", "min", "max"}. In min mode, training will stop when the quantity monitored has stopped decreasing; in "max" mode it will stop when the quantity monitored has stopped increasing; in "auto" mode, the direction is automatically inferred from the name of the monitored quantity.

URI: [https://w3id.org/neat/classifierCallback__mode](https://w3id.org/neat/classifierCallback__mode)


## Domain and Range

None &#8594;  <sub>0..1</sub> [classifier_callback_mode_enum](classifier_callback_mode_enum.md)

## Parents


## Children


## Used by

 * [ClassifierCallback](ClassifierCallback.md)
